@@ -215,15 +215,12 @@ class GoogleCodeWikiExtractor(GoogleCodeProjectExtractor):
 
 
 class GoogleCodeWikiImporter(ToolImporter):
+    target_app = ForgeWikiApp
     source = 'Google Code'
     controller = GoogleCodeWikiImportController
     tool_label = 'Wiki'
     tool_description = 'Import your wiki pages from Google Code'
 
-    @property
-    def target_app(self):
-        return g.entry_points['tool']['wiki']
-
     def import_tool(self, project, user, project_name=None, mount_point=None,
             mount_label=None, **kw):
         """ Import a Google Code wiki into a new ForgeWiki app.
